==> kubernetes-model-apiextensions-5.2.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceConversionBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceConversionBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversion,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionFluent<?> fluent;
    Boolean validationEnabled;

    public CustomResourceConversionBuilder() {
        this(true);
    }

    public CustomResourceConversionBuilder(Boolean validationEnabled) {
        this(new CustomResourceConversion(), validationEnabled);
    }

    public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionFluent<?> fluent) {
        this(fluent, true);
    }

    public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new CustomResourceConversion(), validationEnabled);
    }

    public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversion instance) {
        this(fluent, instance, true);
    }

    public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversion instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withConversionReviewVersions(instance.getConversionReviewVersions()); 
        fluent.withStrategy(instance.getStrategy()); 
        fluent.withWebhookClientConfig(instance.getWebhookClientConfig()); 
        this.validationEnabled = validationEnabled; 
    }

    public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversion instance) {
        this(instance,true);
    }

    public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversion instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withConversionReviewVersions(instance.getConversionReviewVersions()); 
        this.withStrategy(instance.getStrategy()); 
        this.withWebhookClientConfig(instance.getWebhookClientConfig()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversion build() {
        CustomResourceConversion buildable = new CustomResourceConversion(fluent.getConversionReviewVersions(),fluent.getStrategy(),fluent.getWebhookClientConfig());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceConversionBuilder that = (CustomResourceConversionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-apiextensions-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceConversionBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CustomResourceConversionBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversion,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionFluent<?> fluent;
    Boolean validationEnabled;

    public CustomResourceConversionBuilder() {
        this(true);
    }

    public CustomResourceConversionBuilder(Boolean validationEnabled) {
        this(new CustomResourceConversion(), validationEnabled);
    }

    public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionFluent<?> fluent) {
        this(fluent, true);
    }

    public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new CustomResourceConversion(), validationEnabled);
    }

    public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversion instance) {
        this(fluent, instance, true);
    }

    public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversionFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversion instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withConversionReviewVersions(instance.getConversionReviewVersions()); 
        fluent.withStrategy(instance.getStrategy()); 
        fluent.withWebhookClientConfig(instance.getWebhookClientConfig()); 
        this.validationEnabled = validationEnabled; 
    }

    public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversion instance) {
        this(instance,true);
    }

    public CustomResourceConversionBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversion instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withConversionReviewVersions(instance.getConversionReviewVersions()); 
        this.withStrategy(instance.getStrategy()); 
        this.withWebhookClientConfig(instance.getWebhookClientConfig()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceConversion build() {
        CustomResourceConversion buildable = new CustomResourceConversion(fluent.getConversionReviewVersions(),fluent.getStrategy(),fluent.getWebhookClientConfig());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CustomResourceConversionBuilder that = (CustomResourceConversionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
